==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkHyperOctreeFractalSource.java <==
// java wrapper for vtkHyperOctreeFractalSource object
//

package vtk;
import vtk.*;

public class vtkHyperOctreeFractalSource extends vtkHyperOctreeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMaximumLevel_2();
  public int GetMaximumLevel()
    { return GetMaximumLevel_2(); }

  private native void SetMaximumLevel_3(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_3(id0); }

  private native void SetMinimumLevel_4(int id0);
  public void SetMinimumLevel(int id0)
    { SetMinimumLevel_4(id0); }

  private native int GetMinimumLevel_5();
  public int GetMinimumLevel()
    { return GetMinimumLevel_5(); }

  private native void SetProjectionAxes_6(int id0,int id1,int id2);
  public void SetProjectionAxes(int id0,int id1,int id2)
    { SetProjectionAxes_6(id0,id1,id2); }

  private native void SetProjectionAxes_7(int id0[]);
  public void SetProjectionAxes(int id0[])
    { SetProjectionAxes_7(id0); }

  private native int[]  GetProjectionAxes_8();
  public int[]  GetProjectionAxes()
    { return GetProjectionAxes_8(); }

  private native void SetOriginCX_9(double id0,double id1,double id2,double id3);
  public void SetOriginCX(double id0,double id1,double id2,double id3)
    { SetOriginCX_9(id0,id1,id2,id3); }

  private native void SetOriginCX_10(double id0[]);
  public void SetOriginCX(double id0[])
    { SetOriginCX_10(id0); }

  private native double[] GetOriginCX_11();
  public double[] GetOriginCX()
    { return GetOriginCX_11(); }

  private native void SetSizeCX_12(double id0,double id1,double id2,double id3);
  public void SetSizeCX(double id0,double id1,double id2,double id3)
    { SetSizeCX_12(id0,id1,id2,id3); }

  private native void SetSizeCX_13(double id0[]);
  public void SetSizeCX(double id0[])
    { SetSizeCX_13(id0); }

  private native double[] GetSizeCX_14();
  public double[] GetSizeCX()
    { return GetSizeCX_14(); }

  private native void SetMaximumNumberOfIterations_15(int id0);
  public void SetMaximumNumberOfIterations(int id0)
    { SetMaximumNumberOfIterations_15(id0); }

  private native int GetMaximumNumberOfIterationsMinValue_16();
  public int GetMaximumNumberOfIterationsMinValue()
    { return GetMaximumNumberOfIterationsMinValue_16(); }

  private native int GetMaximumNumberOfIterationsMaxValue_17();
  public int GetMaximumNumberOfIterationsMaxValue()
    { return GetMaximumNumberOfIterationsMaxValue_17(); }

  private native int GetMaximumNumberOfIterations_18();
  public int GetMaximumNumberOfIterations()
    { return GetMaximumNumberOfIterations_18(); }

  private native void SetDimension_19(int id0);
  public void SetDimension(int id0)
    { SetDimension_19(id0); }

  private native int GetDimensionMinValue_20();
  public int GetDimensionMinValue()
    { return GetDimensionMinValue_20(); }

  private native int GetDimensionMaxValue_21();
  public int GetDimensionMaxValue()
    { return GetDimensionMaxValue_21(); }

  private native int GetDimension_22();
  public int GetDimension()
    { return GetDimension_22(); }

  private native void SetSpanThreshold_23(double id0);
  public void SetSpanThreshold(double id0)
    { SetSpanThreshold_23(id0); }

  private native double GetSpanThreshold_24();
  public double GetSpanThreshold()
    { return GetSpanThreshold_24(); }

  public vtkHyperOctreeFractalSource() { super(); }

  public vtkHyperOctreeFractalSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-aarch64.pkg.tar.xz: vtk/vtkHyperOctreeFractalSource.java <==
// java wrapper for vtkHyperOctreeFractalSource object
//

package vtk;
import vtk.*;

public class vtkHyperOctreeFractalSource extends vtkHyperOctreeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMaximumLevel_2();
  public int GetMaximumLevel()
    { return GetMaximumLevel_2(); }

  private native void SetMaximumLevel_3(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_3(id0); }

  private native void SetMinimumLevel_4(int id0);
  public void SetMinimumLevel(int id0)
    { SetMinimumLevel_4(id0); }

  private native int GetMinimumLevel_5();
  public int GetMinimumLevel()
    { return GetMinimumLevel_5(); }

  private native void SetProjectionAxes_6(int id0,int id1,int id2);
  public void SetProjectionAxes(int id0,int id1,int id2)
    { SetProjectionAxes_6(id0,id1,id2); }

  private native void SetProjectionAxes_7(int id0[]);
  public void SetProjectionAxes(int id0[])
    { SetProjectionAxes_7(id0); }

  private native int[]  GetProjectionAxes_8();
  public int[]  GetProjectionAxes()
    { return GetProjectionAxes_8(); }

  private native void SetOriginCX_9(double id0,double id1,double id2,double id3);
  public void SetOriginCX(double id0,double id1,double id2,double id3)
    { SetOriginCX_9(id0,id1,id2,id3); }

  private native void SetOriginCX_10(double id0[]);
  public void SetOriginCX(double id0[])
    { SetOriginCX_10(id0); }

  private native double[] GetOriginCX_11();
  public double[] GetOriginCX()
    { return GetOriginCX_11(); }

  private native void SetSizeCX_12(double id0,double id1,double id2,double id3);
  public void SetSizeCX(double id0,double id1,double id2,double id3)
    { SetSizeCX_12(id0,id1,id2,id3); }

  private native void SetSizeCX_13(double id0[]);
  public void SetSizeCX(double id0[])
    { SetSizeCX_13(id0); }

  private native double[] GetSizeCX_14();
  public double[] GetSizeCX()
    { return GetSizeCX_14(); }

  private native void SetMaximumNumberOfIterations_15(int id0);
  public void SetMaximumNumberOfIterations(int id0)
    { SetMaximumNumberOfIterations_15(id0); }

  private native int GetMaximumNumberOfIterationsMinValue_16();
  public int GetMaximumNumberOfIterationsMinValue()
    { return GetMaximumNumberOfIterationsMinValue_16(); }

  private native int GetMaximumNumberOfIterationsMaxValue_17();
  public int GetMaximumNumberOfIterationsMaxValue()
    { return GetMaximumNumberOfIterationsMaxValue_17(); }

  private native int GetMaximumNumberOfIterations_18();
  public int GetMaximumNumberOfIterations()
    { return GetMaximumNumberOfIterations_18(); }

  private native void SetDimension_19(int id0);
  public void SetDimension(int id0)
    { SetDimension_19(id0); }

  private native int GetDimensionMinValue_20();
  public int GetDimensionMinValue()
    { return GetDimensionMinValue_20(); }

  private native int GetDimensionMaxValue_21();
  public int GetDimensionMaxValue()
    { return GetDimensionMaxValue_21(); }

  private native int GetDimension_22();
  public int GetDimension()
    { return GetDimension_22(); }

  private native void SetSpanThreshold_23(double id0);
  public void SetSpanThreshold(double id0)
    { SetSpanThreshold_23(id0); }

  private native double GetSpanThreshold_24();
  public double GetSpanThreshold()
    { return GetSpanThreshold_24(); }

  public vtkHyperOctreeFractalSource() { super(); }

  public vtkHyperOctreeFractalSource(long id) { super(id); }
  public native long   VTKInit();

}
